function d = CRIM13GetInfo(root)
% Function to get info from CRIM13 dataset videos. 
%
% USAGE
%  dataset = CRIM13GetInfo( folder )
%
% INPUTS
%  folder     - path to folder containing videos, annotations and tracks 
%
% OUTPUTS
%  dataset   - interface allowing access to info of videos inside folder
%   .num_videos    - number of behaviors types
%   .num_behaviors - number of videos inside folder     
%   .behaviors     - struct containing info about behavior types
%     .Ids          - behavior Ids (integer)
%     .Names        - behavior names (string)
%   .videos        - struct containing info about each video
%     .NumFrames   - array with number of frames of each video
%     .NamesTop       - full video paths to TOP VIEW videos (string array)
%     .NamesSide      - full video paths to SIDE VIEW videos(string array)
%     .Labels      - cell array with labels for each video and frame
%                       (obtained from .txt annotation file)
%           Labels{video} contains a [1xnFrames] double array, where each value
%           represents the behavior occuring at each frame
%
%     .Tracks      - cell array with mice positions for each video and
%        frame (obtained from -track.mat file) for each top video, 
%        Tracks{video} contains a [nFramesx2x2] double array, where
%           1st dimension is the frame number
%           2nd dimension is mouse type (1=resident, 2=intruder)
%           3rd dimension is mouse position (x,y)
%        *NOTE* intruder is not present at the beginning/end of eahc video,
%        so tracks = [0,0]. The same applies for frames where the tracker
%        failed.
%
% EXAMPLE
%
%  %load info of validation set, training videos
%  d=CRIM13GetInfo('validation/train/');
%
%  %load info of full dataset, testing videos
%  d=CRIM13GetInfo('test/');
%  
%  %get labels for first video
%  labels1 =d.videos.Labels{1};
%
%  %get tracks for first video
%  tracks1 =d.videos.Tracks{1};
%
%  %get behavior names
%  d.behaviors.Names
%
% See also 
%  CodeExamples.m
%
%  Piotr's Matlab toolbox: http://vision.ucsd.edu/~pdollar/toolbox/doc/
%
%
% CRIM13 dataset      Version 1.0
% Copyright 2012 Caltech [vision.caltech.edu]
% Please email X.P. Burgos-Artizzu [xpburgos@caltech.edu] 
% if you find bugs, or have suggestions or questions!
% Licensed under the Lesser GPL 

% If loading full dataset, load stored dinfo
if(exist([root 'dinfo.mat'],'file'))
  fprintf('Loading previously generated dataset information\n');
  load([root 'dinfo.mat']);
else
  fprintf(['Loading full dataset information, setting up dinfo file\n']);
  
%Load dataset info  
[behaviors,bhvNum,videos,num_videos] = loadDataset(root);
  
d = struct('num_videos',num_videos,'num_behaviors',...
  bhvNum,'behaviors', behaviors,'videos',videos);  
  
%Save dataset information for future executions
save([root 'dinfo.mat'],'d');
end
end

function [behaviors,bhvNum,videos,num_videos] = loadDataset(data_dir)
vpaths = dir([data_dir '*t.seq']); num_videos = length(vpaths);
tpaths = dir([data_dir '*track.mat']); lpaths = dir([data_dir '*.txt']);
  
numFrames = zeros(1,num_videos); Names = cell(1,num_videos);
NamesSide = cell(1,num_videos);
Labels = cell(1,num_videos);Tracks = cell(1,num_videos);
for i=1:num_videos
  vpath = vpaths(i).name; A = behaviorData('load',[data_dir lpaths(i).name]);
  if(i==1)
    bhvNames = A.getNames(); bhvIds = 1:length(bhvNames);
    bhvNum = length(bhvNames);
  end
  info = seqIo([data_dir vpath],'getInfo'); numFrames(i)=info.numFrames;
  Labels{i}=A.getLbls(); 
  load([data_dir tpaths(i).name]);%Y 
  pos = zeros(size(Y,3),2,2);
  for k=1:size(Y,3)
    aux = Y{1,1,k}; 
    if(~isempty(aux))
      pos(k,1,:)=aux(1,:);
      if(size(aux,1)>1), pos(k,2,:)=aux(2,:); end
    end
  end
  Tracks{i}=pos; Names{i}=vpath; 
  vpathside=[vpath(1:end-5) 's.seq'];
  if(exist([data_dir vpathside],'file')), NamesSide{i}=vpathside;
  else NamesSide{i}=[]; end
end

videos = struct('NamesTop',[],'NamesSide',[],'NumFrames',[],...
  'Labels',[],'Tracks',[]);
videos.NamesTop=Names; videos.NamesSide=NamesSide;
videos.NumFrames=numFrames;
videos.Labels=Labels;videos.Tracks=Tracks;  

behaviors = struct('Ids',[],'Names',[]);
behaviors.Ids = bhvIds;behaviors.Names = bhvNames;
end